@@ -13,19 +13,19 @@
 # limitations under the License.
 
 from .transport.manager import Manager
-
 from .node_profile import NodeProfile
+from .protocol.message import Message
 
 
 class LocalNode(Manager):
 
     def __init__(self):
-        super(LocalNode, self).__init__()
+        super().__init__()
 
-    def announce_message(self, msg):
-        msg.DEOJ = NodeProfile.OBJECT
-        return super(LocalNode, self).announce_message(msg)
+    def announce_message(self, msg: Message) -> bool:
+        msg.SEOJ = NodeProfile.CODE
+        return super().announce_message(msg)
 
-    def send_message(self, msg, addr):
-        msg.DEOJ = NodeProfile.OBJECT
-        return super(LocalNode, self).send_message(msg, addr)
+    def send_message(self, msg: Message, addr) -> bool:
+        msg.SEOJ = NodeProfile.CODE
+        return super().send_message(msg, addr)
