@@ -12,46 +12,54 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import List, Tuple, Optional, Dict
 from .object import Object
 
 
 class Node(object):
     PORT = 3610
 
+    __address: Optional[Tuple[str, int]]
+    __objects: Dict[int, Object]
+
     def __init__(self):
         self.__address = ()
         self.__objects = {}
 
-    def set_address(self, addr):
+    def set_address(self, addr) -> bool:
         if not isinstance(addr, tuple) or len(addr) != 2:
             return False
         self.__address = addr
         return True
 
     @property
-    def address(self):
+    def address(self) -> Optional[Tuple[str, int]]:
         return self.__address
 
     @property
-    def ip(self):
+    def ip(self) -> str:
+        if len(self.__address) != 2:
+            return ""
         return self.__address[0]
 
     @property
-    def port(self):
+    def port(self) -> int:
+        if len(self.__address) != 2:
+            return 0
         return Node.PORT
 
-    def add_object(self, obj):
+    def add_object(self, obj: Object) -> bool:
         if not isinstance(obj, Object):
             return False
         self.__objects[obj.code] = obj
         return True
 
     @property
-    def objects(self):
+    def objects(self) -> List[Object]:
         objs = []
         for obj in self.__objects.values():
             objs.append(obj)
         return objs
 
-    def has_object(self, code):
+    def has_object(self, code: int) -> bool:
         return code in self.__objects.keys()
